<?php

// Exit if accessed directly
if ( !defined('ABSPATH')) exit;

/**
 * Create HTML list of nav menu items on the HomePage.
 *
 * @since 1.0.0
 * @uses Walker_Nav_Menu
 */
class Walker_Nav_Menu_HomePage extends Walker_Nav_Menu {
	public function __construct( $fields = false ) {
		if ( $fields ) {
			$this->db_fields = $fields;
		}
	}

	/**
	 * Starts the list before the elements are added.
	 *
	 * @see Walker_Nav_Menu::start_lvl()
	 *
	 * @since 1.0.0
	 *
	 * @param string $output Passed by reference. Used to append additional content.
	 * @param int    $depth  Depth of page. Used for padding.
	 * @param array  $args   Not used.
	 */
	public function start_lvl( &$output, $depth = 0, $args = array() ) {
		$indent = str_repeat( "\t", $depth );
//		$output .= "\n$depth: $indent<ul class='children'>\n";
	}

	/**
	 * Ends the list after the elements are added.
	 *
	 * @see Walker_Nav_Menu::end_lvl()
	 *
	 * @since 1.0.0
	 *
	 * @param string $output Passed by reference. Used to append additional content.
	 * @param int    $depth  Depth of page. Used for padding.
	 * @param array  $args   Not used.
	 */
	public function end_lvl( &$output, $depth = 0, $args = array() ) {
		$indent = str_repeat( "\t", $depth );
//		$output .= "\n$depth: $indent</ul>";
	}

	function namonamah_get_default_thumbnail( $show_default = false) {
		$default_thumbnail = $show_default ? get_template_directory_uri() . '/images/default-thumbnail-image.jpg' : '';
	//	if(get_option('opt_nam_use_thumbnail')) {
	//		$default_thumbnail = get_option('opt_nam_thumbnail');
	//		if (empty($default_thumbnail) && $show_default) {
	//			$default_thumbnail = get_template_directory_uri() . '/images/default-thumbnail-image.jpg';
	//		}
	//	}
		return $default_thumbnail;
	}

	function namonamah_get_post_thumbnail( $post_id = null, $show_default = false) {
		$post_thumbnail = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'featured-thumbnail' );
		if (empty($post_thumbnail[0])) {
			$out_thumbnail = $this->namonamah_get_default_thumbnail($show_default);
		} else {
			$out_thumbnail = $post_thumbnail[0];
		}
		return $out_thumbnail;
	}

	/**
	 * Start the element output.
	 *
	 * @see Walker_Nav_Menu::start_el()
	 *
	 * @since 1.0.0
	 *
	 * @param string $output Passed by reference. Used to append additional content.
	 * @param object $item   Menu item data object.
	 * @param int    $depth  Depth of menu item. Used for padding.
	 * @param array  $args   Not used.
	 * @param int    $id     Not used.
	 */
	public function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {
		global $_nav_menu_placeholder;

		$_nav_menu_placeholder = ( 0 > $_nav_menu_placeholder ) ? intval($_nav_menu_placeholder) - 1 : -1;
		$possible_object_id = isset( $item->post_type ) && 'nav_menu_item' == $item->post_type ? $item->object_id : $_nav_menu_placeholder;
		$possible_db_id = ( ! empty( $item->ID ) ) && ( 0 < $possible_object_id ) ? (int) $item->ID : 0;

		if ( ! empty( $item->label ) ) {
			$title = $item->label;
		} elseif ( isset( $item->post_type ) ) {
			/** This filter is documented in wp-includes/post-template.php */
			$title = apply_filters( 'the_title', $item->post_title, $item->ID );
			if ( ! empty( $item->front_or_home ) && _x( 'Home', 'nav menu home label', 'namolite' ) !== $title ) {
				$title = sprintf( _x( 'Home: %s', 'nav menu front page title', 'namolite' ), $title );
			}
		}

		$indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';

		$output .= $indent;
		$output .= '<article id="post-' . $possible_db_id . '" ';
		$output .= 'class="post home item namo-border"> ';
			$output .= '<a href="' . $item->url . '" ';
			$output .= 'title="' . $item->title . '" ';
			$output .= 'rel="bookmark" >';

				// Display the featured image of the post
				$output .= '<div class="home-featured-img" ';
//				$output .= 'style="width:' . intval(get_option('thumbnail_size_w')) . 'px;"';
				$output .= '>';
//				$output .= '<a href="' . $item->url . '" ';
//				$output .= 'title="' . $item->title . '"> ';
					$output .= '<img alt="' . $item->title . '" ';
					$output .= 'src="' . $this->namonamah_get_post_thumbnail($possible_object_id, true) . '" ';
					$output .= 'class="namo-image-border" ';
					$output .= 'width="100%" height="100%" ';
					$output .= '/>';
//				$output .= '</a>';
//				$output .= '<div class="wp-caption">';
//					$output .= $item->title;
//				$output .= '</div>';
				$output .= '</div>';

				// Display the title of the post
				$output .= '<h3 class="post-title">';
					$output .= $item->title;
				$output .= '</h3>';
			$output .= '</a>';

			// Menu item hidden fields
			$output .= '<input type="hidden" class="menu-item-db-id" name="menu-item[' . $possible_object_id . '][menu-item-db-id]" value="' . $possible_db_id . '" />';
			$output .= '<input type="hidden" class="menu-item-db-image" name="menu-item[post-' . $possible_object_id . '][menu-item-db-id]" value="' . $this->namonamah_get_post_thumbnail($possible_db_id, true) . '" />';

			$output .= '<input type="hidden" class="menu-item-object" name="menu-item[' . $possible_object_id . '][menu-item-object]" value="'. esc_attr( $item->object ) .'" />';
			$output .= '<input type="hidden" class="menu-item-parent-id" name="menu-item[' . $possible_object_id . '][menu-item-parent-id]" value="'. esc_attr( $item->menu_item_parent ) .'" />';
			$output .= '<input type="hidden" class="menu-item-type" name="menu-item[' . $possible_object_id . '][menu-item-type]" value="'. esc_attr( $item->type ) .'" />';
			$output .= '<input type="hidden" class="menu-item-title" name="menu-item[' . $possible_object_id . '][menu-item-title]" value="'. esc_attr( $item->title ) .'" />';
			$output .= '<input type="hidden" class="menu-item-url" name="menu-item[' . $possible_object_id . '][menu-item-url]" value="'. esc_attr( $item->url ) .'" />';
			$output .= '<input type="hidden" class="menu-item-target" name="menu-item[' . $possible_object_id . '][menu-item-target]" value="'. esc_attr( $item->target ) .'" />';
			$output .= '<input type="hidden" class="menu-item-attr_title" name="menu-item[' . $possible_object_id . '][menu-item-attr_title]" value="'. esc_attr( $item->attr_title ) .'" />';
			$output .= '<input type="hidden" class="menu-item-classes" name="menu-item[' . $possible_object_id . '][menu-item-classes]" value="'. esc_attr( implode( ' ', $item->classes ) ) .'" />';
			$output .= '<input type="hidden" class="menu-item-xfn" name="menu-item[' . $possible_object_id . '][menu-item-xfn]" value="'. esc_attr( $item->xfn ) .'" />';

		$output .= '</article> <!--.post-->';
	}

} // Walker_Nav_Menu_HomePage
?>