<?php
/**
 * Give this theme some additional widgets.
 *
 * @package Namo Lite
 * @since Namo Lite 1.0
 */

/**
 * A widget for displaying recent category posts
 *
 * Class NamoLite_Category_Posts_Widget
 */
class NamoLite_Category_Posts_Widget extends WP_Widget{

	/**
	 * Register widget with WordPress.
	 */
	function __construct() {

		$widget_ops = array(
				'classname'   => 'widget_namo_entries',
				'description' => __( 'List single category posts.', 'namolite' )
			);

		parent::__construct(
			'namolite-category-posts',
			__('NamoLite Category Posts', 'namolite'),
			$widget_ops
		);

	}

	// Displays category posts widget on blog.
	function widget($args, $instance) {
		global $post;
		$post_old = $post; // Save the post object.

		extract( $args );

		// If not title, use the name of the category.
		if ( !$instance["title"] ) {
			$category_info = get_category($instance["cat"]);
			$instance["title"] = $category_info->name;
		}

		$valid_sort_orders = array('date', 'title', 'comment_count', 'rand');
		if ( in_array($instance['sort_by'], $valid_sort_orders) ) {
			$sort_by = $instance['sort_by'];
			$sort_order = (bool) isset( $instance['asc_sort_order'] ) ? 'ASC' : 'DESC';
		} else {
			// by default, display latest first
			$sort_by = 'date';
			$sort_order = 'DESC';
		}

		// Get array of post info.
		$cat_posts = new WP_Query(
			"showposts=" . $instance["num"] . 
			"&cat=" . $instance["cat"] .
			"&orderby=" . $sort_by .
			"&order=" . $sort_order
		);

		// Excerpt length filter
		$new_excerpt_length = create_function('$length', "return " . $instance["excerpt_length"] . ";");
		if ( $instance["excerpt_length"] > 0 ) {
			add_filter('excerpt_length', $new_excerpt_length);
		}

		echo $before_widget;

		// Widget title
		echo $before_title;
		if( isset( $instance["title_link"] ) ) {
			if( isset( $instance["title_url"] ) ) {
				echo '<a href="' . $instance["title_url"] . '">' . $instance["title"] . '</a>';
			} else {
				echo '<a href="' . get_category_link($instance["cat"]) . '">' . $instance["title"] . '</a>';
			}
		} else {
			echo $instance["title"];
		}
		echo $after_title;

		// Post list
		echo "<ul>\n";

		while ( $cat_posts->have_posts() ) {

			$cat_posts->the_post();
		?>
			<li class="cat-post-item">

				<!-- Use the_post_thumbnail -->
				<?php
					if (
						function_exists('the_post_thumbnail') &&
						current_theme_supports("post-thumbnails") &&
						isset( $instance["thumb"] ) &&
						has_post_thumbnail()
					) :

					// Get the thumb source, width and height
					$thumb_source = wp_get_attachment_image_src( get_post_thumbnail_id(), 'small' );
					$thumb_width  = isset( $instance["thumb_w"] ) ? $instance["thumb_w"] : '32';
					$thumb_height = isset( $instance["thumb_h"] ) ? $instance["thumb_h"] : '32';
				?>
					<a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>">
						<img class="attachment-small alignleft wp-post-image" src="<?php echo $thumb_source[0]; ?>" width="<?php echo $thumb_width; ?>" height="<?php echo $thumb_height; ?>">
					</a>
				<?php endif; ?>

				<!-- Use the_title -->
				<a class="post-title" href="<?php the_permalink(); ?>" rel="bookmark" title="Permanent link to <?php the_title_attribute(); ?>"><?php the_title(); ?></a>

				<!-- Use date -->
				<?php if ( isset( $instance['date'] ) ) : ?>
				<p class="post-date"><?php the_time( get_option( 'date_format' ) ); ?></p>
				<?php endif; ?>

				<!-- Use excerpt -->
				<?php if ( isset( $instance['excerpt'] ) ) : ?>
					<?php the_excerpt(); ?> 
				<?php endif; ?>

				<!-- Use comment_num -->
				<?php if ( isset( $instance['comment_num'] ) ) : ?>
					<p class="comment-num">(<?php comments_number(); ?>)</p>
				<?php endif; ?>
			</li>
			<?php
		}

		echo "</ul>\n";

		echo $after_widget;

		remove_filter('excerpt_length', $new_excerpt_length);

		wp_reset_postdata();

	}

	/**
	 * The widget configuration form back end.
	 *
	 * @param  array $instance
	 * @return void
	 */
	function form($instance) {
		$instance = wp_parse_args( ( array ) $instance, array(
			'title'          => __( '', 'namolite' ),
			'title_url'      => __( '', 'namolite' ),
			'cat'			 => __( '', 'namolite' ),
			'num'            => __( '', 'namolite' ),
			'sort_by'        => __( '', 'namolite' ),
			'asc_sort_order' => __( '', 'namolite' ),
			'title_link'	 => __( '', 'namolite' ),
			'excerpt'        => __( '', 'namolite' ),
			'excerpt_length' => __( '', 'namolite' ),
			'comment_num'    => __( '', 'namolite' ),
			'date'           => __( '', 'namolite' ),
			'thumb'          => __( '', 'namolite' ),
			'thumb_w'        => __( '32', 'namolite' ),
			'thumb_h'        => __( '32', 'namolite' )
		) );

		$title          = $instance['title'];
		$title_url      = $instance['title_url'];
		$cat 			= $instance['cat'];
		$num            = $instance['num'];
		$sort_by        = $instance['sort_by'];
		$asc_sort_order = $instance['asc_sort_order'];
		$title_link		= $instance['title_link'];		
		$excerpt        = $instance['excerpt'];
		$excerpt_length = $instance['excerpt_length'];
		$comment_num    = $instance['comment_num'];
		$date           = $instance['date'];
		$thumb          = $instance['thumb'];
		$thumb_w        = $instance['thumb_w'];
		$thumb_h        = $instance['thumb_h'];

		?>
		<p>
			<label for="<?php echo $this->get_field_id("title"); ?>">
				<?php _e( 'Title', 'namolite' ); ?>:
				<input class="widefat" id="<?php echo $this->get_field_id("title"); ?>" name="<?php echo $this->get_field_name("title"); ?>" type="text" value="<?php echo esc_attr($instance["title"]); ?>" />
			</label>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id("title_url"); ?>">
				<?php _e( 'Title URL', 'namolite' ); ?>:
				<input class="widefat" id="<?php echo $this->get_field_id("title_url"); ?>" name="<?php echo $this->get_field_name("title_url"); ?>" type="text" value="<?php echo esc_attr($instance["title_url"]); ?>" />
			</label>
		</p>

		<p>
			<label>
				<?php _e( 'Category', 'namolite' ); ?>:
				<?php wp_dropdown_categories( array( 'name' => $this->get_field_name("cat"), 'selected' => $instance["cat"] ) ); ?>
			</label>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id("num"); ?>">
				<?php _e('Number of posts to show', 'namolite'); ?>:
				<input style="text-align: center;" id="<?php echo $this->get_field_id("num"); ?>" name="<?php echo $this->get_field_name("num"); ?>" type="text" value="<?php echo absint($instance["num"]); ?>" size='3' />
			</label>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id("sort_by"); ?>">
				<?php _e('Sort by', 'namolite'); ?>:
				<select id="<?php echo $this->get_field_id("sort_by"); ?>" name="<?php echo $this->get_field_name("sort_by"); ?>">
				  <option value="date"<?php selected( $instance["sort_by"], "date" ); ?>>Date</option>
				  <option value="title"<?php selected( $instance["sort_by"], "title" ); ?>>Title</option>
				  <option value="comment_count"<?php selected( $instance["sort_by"], "comment_count" ); ?>>Number of comments</option>
				  <option value="rand"<?php selected( $instance["sort_by"], "rand" ); ?>>Random</option>
				</select>
			</label>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id("asc_sort_order"); ?>">
				<input type="checkbox" class="checkbox" 
				  id="<?php echo $this->get_field_id("asc_sort_order"); ?>" 
				  name="<?php echo $this->get_field_name("asc_sort_order"); ?>"
				  <?php checked( (bool) $instance["asc_sort_order"], true ); ?> />
						<?php _e( 'Reverse sort order (ascending)', 'namolite' ); ?>
			</label>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id("title_link"); ?>">
				<input type="checkbox" class="checkbox" id="<?php echo $this->get_field_id("title_link"); ?>" name="<?php echo $this->get_field_name("title_link"); ?>"<?php checked( (bool) $instance["title_link"], true ); ?> />
				<?php _e( 'Make widget title link', 'namolite' ); ?>
			</label>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id("excerpt"); ?>">
				<input type="checkbox" class="checkbox" id="<?php echo $this->get_field_id("excerpt"); ?>" name="<?php echo $this->get_field_name("excerpt"); ?>"<?php checked( (bool) $instance["excerpt"], true ); ?> />
				<?php _e( 'Show post excerpt', 'namolite' ); ?>
			</label>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id("excerpt_length"); ?>">
				<?php _e( 'Excerpt length (in words):', 'namolite' ); ?>
			</label>
			<input style="text-align: center;" type="text" id="<?php echo $this->get_field_id("excerpt_length"); ?>" name="<?php echo $this->get_field_name("excerpt_length"); ?>" value="<?php echo $instance["excerpt_length"]; ?>" size="3" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id("comment_num"); ?>">
				<input type="checkbox" class="checkbox" id="<?php echo $this->get_field_id("comment_num"); ?>" name="<?php echo $this->get_field_name("comment_num"); ?>"<?php checked( (bool) $instance["comment_num"], true ); ?> />
				<?php _e( 'Show number of comments', 'namolite' ); ?>
			</label>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id("date"); ?>">
				<input type="checkbox" class="checkbox" id="<?php echo $this->get_field_id("date"); ?>" name="<?php echo $this->get_field_name("date"); ?>"<?php checked( (bool) $instance["date"], true ); ?> />
				<?php _e( 'Show post date', 'namolite' ); ?>
			</label>
		</p>

		<?php if ( function_exists('the_post_thumbnail') && current_theme_supports("post-thumbnails") ) : ?>
		<p>
			<label for="<?php echo $this->get_field_id("thumb"); ?>">
				<input type="checkbox" class="checkbox" id="<?php echo $this->get_field_id("thumb"); ?>" name="<?php echo $this->get_field_name("thumb"); ?>"<?php checked( (bool) $instance["thumb"], true ); ?> />
				<?php _e( 'Show post thumbnail', 'namolite' ); ?>
			</label>
		</p>
		<p>
			<p>
				<?php _e('Thumbnail dimensions (in pixels)', 'namolite'); ?>:<br />
				<label for="<?php echo $this->get_field_id("thumb_w"); ?>">
					Width: <input class="widefat" style="width:30%;" type="text" id="<?php echo $this->get_field_id("thumb_w"); ?>" name="<?php echo $this->get_field_name("thumb_w"); ?>" value="<?php echo $instance["thumb_w"]; ?>" />px;
				</label>

				<label for="<?php echo $this->get_field_id("thumb_h"); ?>">
					Height: <input class="widefat" style="width:30%;" type="text" id="<?php echo $this->get_field_id("thumb_h"); ?>" name="<?php echo $this->get_field_name("thumb_h"); ?>" value="<?php echo $instance["thumb_h"]; ?>" />px;
				</label>
			</p>
		</p>
		<?php endif; ?>

		<?php

	}

	/**
	 * Update the options
	 *
	 * @param  array $new_instance
	 * @param  array $old_instance
	 * @return array
	 */
	function update($new_instance, $old_instance) {

		// Check the title url
		if( isset( $new_instance["title_url"] ) ) {
			$new_instance["title_url"] = esc_url($new_instance["title_url"]);
		}

		return $new_instance;
	}
}

/**
 * Register the NamoLite specific widgets.
 */
function namolite_register_widgets(){
	register_widget('NamoLite_Category_Posts_Widget');
}
add_action( 'widgets_init', 'namolite_register_widgets');
